# Release history

### 0.0.4
* Add CI/CD.

### 0.0.3
* Restructure commands directory.
* Add entry points for every section e.g. `jira`, `jira.sprints`, and `jira.sprints.storypoints`.
* Update README.

### 0.0.2
* Add readme.

### 0.0.1
* Initial build.
* Exposed one command to list story points for a given sprint.
